<!DOCTYPE html>
<html>
    <head>
        <link href="{{ url_for('static', filename='favicon.ico') }}" rel="shortcut icon" type="image/x-icon" />
        <link href="{{ url_for('static', filename='vendor/initializr/css/bootstrap.min.css') }}" rel="stylesheet" type="text/css" />
        <link href="{{ url_for('static', filename='vendor/initializr/css/main.css') }}" rel="stylesheet" type="text/css" />

        <meta charset="utf-8">
        <meta name="description" content="">
        <meta name="viewport" content="width=device-width">

        <script src="{{ url_for('static', filename='vendor/initializr/js/vendor/modernizr-2.6.1-respond-1.1.0.min.js') }}"></script>
        <style>body {padding-top:60px;padding-bottom:40px;}</style>

        <title>inupypi - A Multi Repository PyPI Server</title>
    </head>

    <body><!--[if lt IE 7]><p class="chromeframe">You are using an outdated browser. <a href="http://browsehappy.com/">Upgrade your browser today</a> or <a href="http://www.google.com/chromeframe/?redirect=true">install Google Chrome Frame</a> to better experience this site.</p><![endif]-->
        <header>
        <div class="navbar navbar-inverse navbar-fixed-top">
            <div class="navbar-inner">
                <div class="container">
                    <a class="brand" href="{{ url_for('main.index') }}">inupypi - A Multi Repository PyPI Server</a>

                    <div class="nav-collapse collapse">
                        <ul class="nav"></ul>
                    </div>
                </div>
            </div>
        </div>
        </header>

        <div class="container">
            {% if sticky_header %}<div class="hero-unit">{% block sticky_header %}{% endblock %}</div>{% endif %}
            <div>
                {% block content %}{% endblock %}
            </div>

            <div class="row"><p>&nbsp;</p></div>

            <footer class="muted">
                <p><small>Powered by <a href="http://flask.pocoo.org/" title="Powered by Flask">Flask</a>
                    <span>&nbsp; | &nbsp;</span>
                <a href="https://github.com/hallaj/inupypi/" title="inupypi">inupypi 0.3</a></small></p>
            </footer>
        </div>

        <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.8.2/jquery.min.js"></script>
        <script src="{{ url_for('static', filename='vendor/tablesorter/jquery.tablesorter.min.js') }}"></script>
        <script src="{{ url_for('static', filename='vendor/initializr/js/vendor/bootstrap.min.js') }}"></script>
        <script src="{{ url_for('static', filename='vendor/initializr/js/main.js') }}"></script>
    </body>
</html>
