{% extends theme('base.html') %}
{% block content %}
<h4>500: Internal Server Error</h4>
<p>There was an internal server error recorded: <span class="label label-important">{{ error.description }}</span></p>
{% endblock %}
